Use "progdlg_t *" rather than "void *" as the handle for a progress
[obnox/wireshark/wip.git] / file.h
diff --git a/file.h b/file.h
index a09675e083713f923cd3b5c8a58b176c0bfca4a2..b91cfbba68f52377cd2924bdb0fa22da4b7fdfa4 100644 (file)
--- a/file.h
+++ b/file.h
@@ -1,7 +1,7 @@
 /* file.h
  * Definitions for file structures and routines
  *
- * $Id: file.h,v 1.61 1999/12/10 04:20:53 gram Exp $
+ * $Id: file.h,v 1.70 2000/07/03 08:35:41 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -45,7 +45,7 @@
 #endif
 
 #ifndef __COLORS_H__
-#include "colors.h"
+#include "gtk/colors.h"                /* XXX */
 #endif
 
 #ifndef __PRINT_H__
 
 #ifdef HAVE_LIBZ
 #include "zlib.h"
-
 #define FILE_T gzFile
 #define file_open gzopen
 #define filed_open gzdopen
-#define file_seek gzseek
-#define file_read(buf, bsize, count, file) gzread((file),(buf),((count)*(bsize)))
-#define file_write(buf, bsize, count, file) gzwrite((file),(buf),((count)*(bsize)))
 #define file_close gzclose
-
 #else /* No zLib */
 #define FILE_T FILE *
 #define file_open fopen
 #define filed_open fdopen
-#define file_seek fseek
-#define file_read fread
-#define file_write fwrite
 #define file_close fclose
 #endif /* HAVE_LIBZ */
 
 typedef struct bpf_program bpf_prog;
 
+/* Current state of file. */
+typedef enum {
+       FILE_CLOSED,            /* No file open */
+       FILE_READ_IN_PROGRESS,  /* Reading a file we've opened */
+       FILE_READ_ABORTED,      /* Read aborted by user */
+       FILE_READ_DONE          /* Read completed */
+} file_state;
+
 typedef struct _capture_file {
-  FILE_T       fh;        /* File handle for capture file */
+  file_state   state;     /* Current state of capture file */
   int          filed;     /* File descriptor of capture file */
   gchar       *filename;  /* Name of capture file */
   gboolean     is_tempfile; /* Is capture file a temporary file? */
@@ -88,12 +88,10 @@ typedef struct _capture_file {
   int          lnk_t;     /* Link-layer type with which to save capture */
   guint32      vers;      /* Version.  For tcpdump minor is appended to major */
   guint32      count;     /* Packet count */
-  gfloat       unfiltered_count; /* used for dfilter progress bar */
   guint32      drops;     /* Dropped packets */
   guint32      esec;      /* Elapsed seconds */
   guint32      eusec;     /* Elapsed microseconds */
   guint32      snap;      /* Captured packet length */
-  gboolean     update_progbar; /* TRUE if we should update the progress bar */
   long         progbar_quantum; /* Number of bytes read per progress bar update */
   long         progbar_nextstep; /* Next point at which to update progress bar */
   gchar       *iface;     /* Interface */
@@ -110,25 +108,33 @@ typedef struct _capture_file {
 #endif
   gchar       *sfilter;   /* Search filter string */
   gboolean     sbackward;  /* TRUE if search is backward, FALSE if forward */
+  union wtap_pseudo_header pseudo_header;      /* Packet pseudo_header */
   guint8       pd[WTAP_MAX_PACKET_SIZE];  /* Packet data */
+  GMemChunk   *plist_chunk; /* Memory chunk for frame_data structures */
   frame_data  *plist;     /* Packet list */
   frame_data  *plist_end; /* Last packet in list */
   frame_data  *first_displayed; /* First frame displayed */
   frame_data  *last_displayed;  /* Last frame displayed */
   column_info  cinfo;    /* Column formatting information */
   frame_data  *current_frame;  /* Frame data for current frame */
-  int          current_row;    /* Row in packet display of current frame */
-  gboolean     current_frame_is_selected; /* TRUE if that frame is selected */
   proto_tree  *protocol_tree; /* Protocol tree for currently selected packet */
   FILE        *print_fh;  /* File we're printing to */
 } capture_file;
 
+/* Return values from "read_cap_file()", "continue_tail_cap_file()",
+   and "finish_tail_cap_file()". */
+typedef enum {
+       READ_SUCCESS,   /* read succeeded */
+       READ_ERROR,     /* read got an error */
+       READ_ABORTED    /* read aborted by user */
+} read_status_t;
+
 int  open_cap_file(char *, gboolean, capture_file *);
 void close_cap_file(capture_file *, void *);
-int  read_cap_file(capture_file *);
+read_status_t read_cap_file(capture_file *, int *);
 int  start_tail_cap_file(char *, gboolean, capture_file *);
-int  continue_tail_cap_file(capture_file *, int);
-int  finish_tail_cap_file(capture_file *);
+read_status_t continue_tail_cap_file(capture_file *, int, int *);
+read_status_t finish_tail_cap_file(capture_file *, int *);
 /* size_t read_frame_header(capture_file *); */
 int  save_cap_file(char *, capture_file *, gboolean, guint);